@@ -221,11 +221,12 @@ class RestStore(BasicStore):
         :returns: The raw file data.
         :rtype: numpy.ndarray|list
         """
-        tmphandler, tmppath = tempfile.mkstemp()
+        fd, tmppath = tempfile.mkstemp()
         with open(tmppath, 'w') as f:
             f.write(self.get_file(location))
 
         array_data = read_array_data(tmppath)
+        os.close(fd)
         os.remove(tmppath)
         return array_data
 
@@ -295,22 +296,26 @@ class RestStore(BasicStore):
         :returns: The url to the uploaded file.
         :rtype: str
         """
-        tmphandler, tmppath = tempfile.mkstemp()
+        fd, tmppath = tempfile.mkstemp()
         store_array_data(tmppath, array_data)
         with open(tmppath, 'rb') as f:
             location = self.set_file(f.read())
+
+        os.close(fd)
         os.remove(tmppath)
         return location
 
-    def delete(self, entity):
+    def delete(self, entity_or_location):
         """
         Delete an entity from the G-Node REST API.
 
-        :param entity: The entity to delete.
-        :type entity: Model
+        :param entity_or_location: The entity to delete.
+        :type entity_or_location: Model or string
         """
-        if hasattr(entity, "location") and entity.location is not None:
-            url = urlparse.urljoin(self.location, entity.location)
+        if type(entity_or_location) == str:
+            url = urlparse.urljoin(self.location, entity_or_location)
+        elif hasattr(entity_or_location, "location") and entity_or_location.location is not None:
+            url = urlparse.urljoin(self.location, entity_or_location.location)
         else:
             raise RuntimeError("The entity has no location and can therefore not be deleted.")
 
